@@ -1,26 +1,27 @@
-/* This file is part of Patchage.  Copyright (C) 2005 Dave Robillard.
+/* This file is part of Patchage.
+ * Copyright (C) 2007 Dave Robillard <http://drobilla.net>
  * 
- * Om is free software; you can redistribute it and/or modify it under the
+ * Patchage is free software; you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software
  * Foundation; either version 2 of the License, or (at your option) any later
  * version.
  * 
- * Om is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Patchage is distributed in the hope that it will be useful, but WITHOUT ANY
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for details.
  * 
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
-#include "config.h"
+#include CONFIG_H_PATH
 
 #include <iostream>
 #include <libgnomecanvasmm.h>
+#include <glibmm/exception.h>
 
-#include "Patchage.h"
-#include "JackDriver.h"
+#include "Patchage.hpp"
 
 #ifdef HAVE_LASH
 #include <lash/lash.h>
@@ -29,17 +30,23 @@
 int main(int argc, char** argv)
 {
 	try {
-		
+	
+	Glib::thread_init();
+
 	Gnome::Canvas::init();
 	Gtk::Main app(argc, argv);
 	
 	Patchage patchage(argc, argv);
-	patchage.attach();
-
 	app.run(*patchage.window());
 	
-	} catch (std::string msg) {
-		std::cerr << "Caught exception, aborting.  Error message was: " << msg << std::endl;
+	} catch (std::exception& e) {
+		std::cerr << "Caught exception, aborting.  Error message was: "
+				<< e.what() << std::endl;
+		return 1;
+	
+	} catch (Glib::Exception& e) {
+		std::cerr << "Caught exception, aborting.  Error message was: "
+				<< e.what() << std::endl;
 		return 1;
 	}
 
